[Openchrome-devel] xf86-video-openchrome: src/via_display.c src/via_ums.h

Kevin Brace kevinbrace at kemper.freedesktop.org
Tue May 10 04:58:15 UTC 2016


 src/via_display.c |   24 ++++++++++++------------
 src/via_ums.h     |    2 +-
 2 files changed, 13 insertions(+), 13 deletions(-)

New commits:
commit ce962f0dc1c2dacb2854164b10975f29372a571f
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Mon May 9 21:51:46 2016 -0700

    Changing viaIGA2Screen to viaIGA2DisplayOutput
    
    Based on the feedback I received from other developers, the function
    name is changing. Furthermore, other small changes were made to the
    function's code. This function is located inside via_display.c.
    
    Suggested-by: Bartosz Kosiorek <gang65 at poczta.onet.pl>
    Suggested-by: Luc Verhaegen <libv at skynet.be>
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_ums.h b/src/via_ums.h
index 30665e0..541757b 100644
--- a/src/via_ums.h
+++ b/src/via_ums.h
@@ -209,7 +209,7 @@ void ViaSetUseExternalClock(vgaHWPtr hwp);
 
 /* via_display.c */
 void viaIGA1DPMSControl(ScrnInfoPtr pScrn, CARD8 DPMS_Control);
-void viaIGA2Screen(ScrnInfoPtr pScrn, Bool Screen_State);
+void viaIGA2DisplayOutput(ScrnInfoPtr pScrn, Bool OutputEnable);
 void viaIGA2DisplayChannel(ScrnInfoPtr pScrn, Bool Channel_State);
 void viaDisplayInit(ScrnInfoPtr pScrn);
 void ViaDisplayEnableSimultaneous(ScrnInfoPtr pScrn);


More information about the Openchrome-devel mailing list
diff --git a/src/via_display.c b/src/via_display.c
index 832a1da..f1bdc83 100644
--- a/src/via_display.c
+++ b/src/via_display.c
@@ -50,23 +50,23 @@ viaIGA1DPMSControl(ScrnInfoPtr pScrn, CARD8 DPMS_Control)
 }
 
 /*
  * Controls IGA2 screen state.
  */
 void
-viaIGA2Screen(ScrnInfoPtr pScrn, Bool Screen_State)
+viaIGA2DisplayOutput(ScrnInfoPtr pScrn, Bool OutputEnable)
 {
     vgaHWPtr hwp = VGAHWPTR(pScrn);
 
     DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Entered viaIGA2Screen.\n"));
+                        "Entered viaIGA2DisplayOutput.\n"));
 
-    /* 3X5.6B[2]: IGA2 Screen Off
-     * 0 = Screen on
-     * 1 = Screen off */
-    ViaCrtcMask(hwp, 0x6B, Screen_State ? 0x00 : 0x04, 0x04);
+    /* 3X5.6B[2] - IGA2 Screen Off
+     *             0: Screen on
+     *             1: Screen off */
+    ViaCrtcMask(hwp, 0x6B, OutputEnable ? 0x00 : 0x04, 0x04);
 
     DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Exiting viaIGA2Screen.\n"));
+                        "Exiting viaIGA2DisplayOutput.\n"));
 }
 
 /*
@@ -2486,7 +2486,7 @@ iga2_crtc_dpms(xf86CrtcPtr crtc, int mode)
 
     switch (mode) {
     case DPMSModeOn:
-        viaIGA2Screen(pScrn, TRUE);
+        viaIGA2DisplayOutput(pScrn, TRUE);
 
         if (pBIOSInfo->SimultaneousEnabled)
             ViaDisplayEnableSimultaneous(pScrn);
@@ -2495,7 +2495,7 @@ iga2_crtc_dpms(xf86CrtcPtr crtc, int mode)
     case DPMSModeStandby:
     case DPMSModeSuspend:
     case DPMSModeOff:
-        viaIGA2Screen(pScrn, FALSE);
+        viaIGA2DisplayOutput(pScrn, FALSE);
 
         if (pBIOSInfo->SimultaneousEnabled)
             ViaDisplayDisableSimultaneous(pScrn);
@@ -2626,7 +2626,7 @@ iga2_crtc_mode_set(xf86CrtcPtr crtc, DisplayModePtr mode,
     }
 
     /* Turn off IGA2 during mode setting. */
-    viaIGA2Screen(pScrn, FALSE);
+    viaIGA2DisplayOutput(pScrn, FALSE);
 
     viaIGAInitCommon(pScrn);
     ViaCRTCInit(pScrn);
@@ -2641,7 +2641,7 @@ iga2_crtc_mode_set(xf86CrtcPtr crtc, DisplayModePtr mode,
     iga2_crtc_set_origin(crtc, crtc->x, crtc->y);
 
     /* Turn on IGA2 now that mode setting is done. */
-    viaIGA2Screen(pScrn, TRUE);
+    viaIGA2DisplayOutput(pScrn, TRUE);
 
     DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
                         "Exiting iga2_crtc_mode_set.\n"));
@@ -50,23 +50,23 @@ viaIGA1DPMSControl(ScrnInfoPtr pScrn, CARD8 DPMS_Control)
 
 /*
- * Controls IGA2 screen state.
+ * Controls IGA2 display output on or off state.
  */
 void